// #############################################################################
// #                     --- Flashlight Controller ---                         #
// #############################################################################
// # main.h - Header for main program                                          #
// #############################################################################
// #              Version: 1.0 - Compiler: AVR-GCC 4.5.0 (Linux)               #
// #  (c) 2012 by Malte Pöggel - www.MALTEPOEGGEL.de - malte@maltepoeggel.de   #
// #############################################################################
// #  This program is free software; you can redistribute it and/or modify it  #
// #   under the terms of the GNU General Public License as published by the   #
// #        Free Software Foundation; either version 3 of the License,         #
// #                  or (at your option) any later version.                   #
// #                                                                           #
// #      This program is distributed in the hope that it will be useful,      #
// #      but WITHOUT ANY WARRANTY; without even the implied warranty of       #
// #           MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
// #           See the GNU General Public License for more details.            #
// #                                                                           #
// #  You should have received a copy of the GNU General Public License along  #
// #      with this program; if not, see <http://www.gnu.org/licenses/>.       #
// #############################################################################

#ifndef MAIN_H
 #define MAIN_H

 #include <avr/io.h>
 #include <avr/pgmspace.h>

 #define MODE_BRIGHT_7 0
 #define MODE_BRIGHT_6 1
 #define MODE_BRIGHT_5 2
 #define MODE_BRIGHT_4 3
 #define MODE_BRIGHT_3 4
 #define MODE_BRIGHT_2 5
 #define MODE_BRIGHT_1 6
 #define MODE_BLINK    7
 #define MODE_STROBE   8
 #define MODE_FLASH    9
 #define MODE_SOS     10
 #define MODE_ALPINE  11
 #define MODE_FADE    12
 #define MODE_SPOOKY  13
 #define MODE_NONE   255

 #define NO_MODES      6
 #define MAX_MODES    12
 
 // ADC values
 // (Divider 680R / 150R, Vref=1.1V)
 // 3,00V: 675 <- LiIon / LiPo
 // 2,75V: 619
 // 2,50V: 563
 // 2,25V: 506
 // 2,00V: 450 <- LiFePo4
 #define BATT_MIN    450

 const uint8_t mode_array[NO_MODES][(MAX_MODES+1)] PROGMEM = {
  { 3, MODE_BRIGHT_7, MODE_BRIGHT_5, MODE_BRIGHT_3, MODE_NONE,     MODE_NONE,     MODE_NONE,     MODE_NONE,     MODE_NONE,  MODE_NONE, MODE_NONE,   MODE_NONE, MODE_NONE   },
  { 5, MODE_BRIGHT_7, MODE_BRIGHT_6, MODE_BRIGHT_5, MODE_BRIGHT_4, MODE_BRIGHT_3, MODE_NONE,     MODE_NONE,     MODE_NONE,  MODE_NONE, MODE_NONE,   MODE_NONE, MODE_NONE   },
  { 7, MODE_BRIGHT_7, MODE_BRIGHT_6, MODE_BRIGHT_5, MODE_BRIGHT_4, MODE_BRIGHT_3, MODE_BRIGHT_2, MODE_BRIGHT_1, MODE_NONE,  MODE_NONE, MODE_NONE,   MODE_NONE, MODE_NONE   },
  { 7, MODE_BRIGHT_7, MODE_BRIGHT_6, MODE_BRIGHT_5, MODE_BRIGHT_4, MODE_BRIGHT_3, MODE_STROBE,   MODE_SOS,      MODE_NONE,  MODE_NONE, MODE_NONE,   MODE_NONE, MODE_NONE   },
  { 8, MODE_BRIGHT_7, MODE_BRIGHT_6, MODE_BRIGHT_5, MODE_BRIGHT_4, MODE_BRIGHT_3, MODE_BLINK,    MODE_STROBE,   MODE_FLASH, MODE_NONE, MODE_NONE,   MODE_NONE, MODE_NONE   },
  {12, MODE_BRIGHT_7, MODE_BRIGHT_6, MODE_BRIGHT_5, MODE_BRIGHT_4, MODE_BRIGHT_3, MODE_BLINK,    MODE_STROBE,   MODE_FLASH, MODE_SOS,  MODE_ALPINE, MODE_FADE, MODE_SPOOKY },
 };

 const uint8_t sos_pattern[60] PROGMEM = { 0xFF, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0x00, 0xF0, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xFF, 0x00, 0x00, 0xF0, 0x0F, 0xF0, 0x0F, 0xF0, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00 };

#endif
