// #############################################################################
// #                     --- Flashlight Controller ---                         #
// #############################################################################
// # prng.h - Pseudo random number generator                                   #
// #############################################################################
// #              Version: 1.0 - Compiler: AVR-GCC 4.5.0 (Linux)               #
// #  (c) 2012 by Malte Pöggel - www.MALTEPOEGGEL.de - malte@maltepoeggel.de   #
// #############################################################################
// #  This program is free software; you can redistribute it and/or modify it  #
// #   under the terms of the GNU General Public License as published by the   #
// #        Free Software Foundation; either version 3 of the License,         #
// #                  or (at your option) any later version.                   #
// #                                                                           #
// #      This program is distributed in the hope that it will be useful,      #
// #      but WITHOUT ANY WARRANTY; without even the implied warranty of       #
// #           MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.            #
// #           See the GNU General Public License for more details.            #
// #                                                                           #
// #  You should have received a copy of the GNU General Public License along  #
// #      with this program; if not, see <http://www.gnu.org/licenses/>.       #
// #############################################################################

// Source:
// http://www.mikrocontroller.net/topic/112114
// http://en.wikipedia.org/wiki/Linear_congruential_generator

 #include <avr/io.h>
 #include "prng.h"

 uint8_t g_nLastRandom = 1;


 void prng_seed( uint8_t nSeed )
  {
   g_nLastRandom = nSeed;
  }


 uint8_t prng_get( void )
  {
   //copy into local variables to avoid 16-bit integer expansion
   uint8_t Multiplier = PRNG_MULTIPLIER;
   uint8_t Constant = PRNG_CONSTANT;

   //implicit %256 by 8-bit datatype overflow
   g_nLastRandom = (g_nLastRandom * Multiplier + Constant);
  
   return g_nLastRandom;
  }
